"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _AsyncPickerResult = _interopRequireDefault(require("./components/AsyncPickerResult"));

var _DefaultButton = _interopRequireDefault(require("./components/DefaultButton"));

var _Header = _interopRequireDefault(require("./components/Header"));

var _LinkButton = _interopRequireDefault(require("./components/LinkButton"));

var _PickerItem = _interopRequireDefault(require("./components/PickerItem"));

var _AsyncPickerContext = require("./utils/AsyncPickerContext");

var _helpers = require("./utils/helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const AsyncPickerComponent = (_ref, ref) => {
  let {
    modalProps,
    statusBarProps,
    headerProps,
    renderItem,
    keyExtractor,
    labelExtractor,
    data = [],
    limit = 0,
    value = [],
    onChange,
    isLoading = false,
    closeOnSelect = false,
    onClose,
    defaultButtonProps,
    label,
    isSearchable = true,
    searchStringExtractor,
    searchProps,
    defaultPickerItemProps,
    renderButton = _ref2 => {
      let {
        openModal
      } = _ref2;
      return /*#__PURE__*/_react.default.createElement(_DefaultButton.default, _extends({
        label: label,
        onPress: openModal,
        placeholder: value && value.length > 0 ? value.map(el => labelExtractor ? labelExtractor(el) : keyExtractor(el)).join(', ') : undefined
      }, defaultButtonProps));
    },
    ...props
  } = _ref;
  const [isModalVisible, setIsModalVisible] = (0, _react.useState)(false);
  const [searchQuery, setSearchQuery] = (0, _react.useState)('');
  const {
    configs
  } = (0, _AsyncPickerContext.useAsyncPicker)();
  const inputRef = (0, _react.useRef)(null);

  const openModal = () => setIsModalVisible(true);

  const closeModal = () => setIsModalVisible(false);

  const onOptionPress = option => {
    if (limit !== 1) {
      if (value.find(el => keyExtractor(el) === keyExtractor(option))) {
        onChange(value.filter(el => keyExtractor(el) !== keyExtractor(option)));
        return;
      }
    }

    const selectedItems = limit === 1 ? [option] : [...value, option];

    if (limit && limit > 1 && selectedItems.length > limit) {
      return;
    }

    onChange(selectedItems);

    if (onClose) {
      onClose();
    }

    if (closeOnSelect) {
      closeModal();
    }
  };

  const getSearchResult = (query, _data) => {
    const result = _data.filter(el => (0, _helpers.isTextIncludedInString)(query, searchStringExtractor ? searchStringExtractor(el) : labelExtractor(el)));

    return result || [];
  };

  _react.default.useImperativeHandle(ref, () => ({
    openModal,
    closeModal,
    triggerOptionPress: el => {
      onOptionPress(el);
    },
    reset: () => {
      if (onChange) {
        onChange([]);
      }
    },
    getLocalSearchQuery: () => searchQuery,
    focusOnSearch: () => {
      if (inputRef.current) {
        console.log('hello focus');
        inputRef.current.focus();
      }
    }
  }));

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, null, renderButton({
    openModal,
    value
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Modal, _extends({
    animationType: "slide",
    presentationStyle: "formSheet",
    transparent: false,
    visible: isModalVisible,
    onRequestClose: () => {
      closeModal();
    }
  }, modalProps), /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: [{
      flex: 1
    }, configs.containerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.StatusBar, _extends({
    barStyle: _reactNative.Platform.OS === 'ios' ? 'light-content' : 'dark-content'
  }, statusBarProps)), /*#__PURE__*/_react.default.createElement(_Header.default, _extends({
    label: "Search",
    right: /*#__PURE__*/_react.default.createElement(_LinkButton.default, {
      label: "Close",
      onPress: closeModal,
      style: configs.headerTextStyle
    }),
    left: isLoading ? /*#__PURE__*/_react.default.createElement(_reactNative.ActivityIndicator, null) : undefined
  }, headerProps)), isSearchable && /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, _extends({
    ref: inputRef,
    placeholder: 'Search ...',
    autoCapitalize: "none",
    autoCorrect: false,
    clearButtonMode: "while-editing",
    selectTextOnFocus: true
  }, searchProps, {
    value: (searchProps === null || searchProps === void 0 ? void 0 : searchProps.value) || searchQuery,
    onChangeText: el => {
      setSearchQuery(el);

      if (searchProps !== null && searchProps !== void 0 && searchProps.onChangeText) {
        searchProps.onChangeText(el);
      }
    },
    style: [configs.searchInputStyle, searchProps === null || searchProps === void 0 ? void 0 : searchProps.style]
  })), /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, _extends({
    data: searchQuery ? getSearchResult(searchQuery, data) : data,
    keyExtractor: keyExtractor,
    renderItem: _ref3 => {
      let {
        item,
        index,
        separators
      } = _ref3;
      const isActive = value.some(el => keyExtractor(el) === keyExtractor(item));
      const disabled = !isActive && !!limit && limit > 1 && value.length === limit;
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, renderItem ? renderItem({
        item,
        index,
        separators,
        isActive,
        disabled,
        closeModal,
        onItemPress: onOptionPress
      }) : /*#__PURE__*/_react.default.createElement(_PickerItem.default, _extends({
        label: labelExtractor(item),
        isActive: isActive,
        disabled: disabled,
        onPress: () => onOptionPress(item)
      }, defaultPickerItemProps)));
    },
    ListEmptyComponent: /*#__PURE__*/_react.default.createElement(_AsyncPickerResult.default, {
      mode: !searchQuery ? 'beforeSearch' : 'afterSearch',
      isVisible: !isLoading
    })
  }, props)))));
};

var _default = /*#__PURE__*/(0, _react.forwardRef)(AsyncPickerComponent);

exports.default = _default;
//# sourceMappingURL=AsyncPicker.js.map