"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AsyncPickerProvider = void 0;
exports.useAsyncPicker = useAsyncPicker;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _colors = require("./colors");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultSizes = {
  screenPadding: 16,
  buttonHeight: 54,
  searchHeight: 54,
  chipsItemHeight: 44,
  chipsItemBorderRadius: 12,
  chipsItemGapSize: 6,
  chipsItemPaddingLeft: 12,
  chipsItemPaddingRight: 12,
  checkboxSize: 20,
  checkboxBorderRadius: 4
};

const getInitialConfigs = function (props) {
  let scheme = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'light';
  const baseColors = { ..._colors.defaultColors[scheme],
    ...(props === null || props === void 0 ? void 0 : props.colors)
  };
  const sizes = { ...defaultSizes,
    ...(props === null || props === void 0 ? void 0 : props.sizes)
  };
  const defaultTextStyle = [{
    color: baseColors.textDefaultColor
  }, props === null || props === void 0 ? void 0 : props.textBaseStyle];
  return {
    colors: baseColors,
    sizes: sizes,
    textBaseStyle: defaultTextStyle,
    textLinkStyle: [...defaultTextStyle, {
      color: baseColors.textLinkColor
    }, props === null || props === void 0 ? void 0 : props.textLinkStyle],
    buttonContainerStyle: [{}, props === null || props === void 0 ? void 0 : props.buttonContainerStyle],
    buttonStyle: [{
      minHeight: sizes.buttonHeight,
      flexDirection: 'row',
      alignItems: 'center',
      justifyContent: 'space-between',
      backgroundColor: baseColors.buttonBackgroundColor,
      borderWidth: 1,
      borderColor: baseColors.buttonBorderColor,
      borderRadius: 10,
      paddingHorizontal: 16,
      paddingVertical: 5
    }, props === null || props === void 0 ? void 0 : props.buttonStyle],
    buttonLabelStyle: [...defaultTextStyle, {
      color: baseColors.buttonLabelColor,
      fontWeight: 'bold',
      marginVertical: 4
    }, props === null || props === void 0 ? void 0 : props.buttonLabelStyle],
    buttonTextStyle: [...defaultTextStyle, {
      color: baseColors.buttonTextColor,
      fontWeight: 'bold',
      flex: 1
    }, props === null || props === void 0 ? void 0 : props.buttonTextStyle],
    buttonCaretImageStyle: [{
      width: 20,
      height: 20,
      tintColor: baseColors.buttonCaretColor
    }, props === null || props === void 0 ? void 0 : props.buttonCaretImageStyle],
    containerStyle: [{
      backgroundColor: baseColors.backgroundColor
    }, props === null || props === void 0 ? void 0 : props.containerStyle],
    chipsGridStyle: [{
      flexDirection: 'row',
      alignItems: 'center',
      flexWrap: 'wrap',
      marginLeft: -sizes.chipsItemGapSize / 2,
      marginRight: -sizes.chipsItemGapSize / 2
    }, props === null || props === void 0 ? void 0 : props.chipsGridStyle],
    chipsItemContainerStyle: [{
      flexDirection: 'row',
      justifyContent: 'center',
      alignItems: 'center',
      minHeight: sizes.chipsItemHeight,
      borderRadius: sizes.chipsItemBorderRadius,
      margin: sizes.chipsItemGapSize / 2,
      paddingLeft: sizes.chipsItemPaddingLeft,
      paddingRight: sizes.chipsItemPaddingRight,
      backgroundColor: baseColors.chipsItemBackgroundColor,
      borderWidth: 1,
      borderColor: baseColors.chipsItemBorderColor
    }, props === null || props === void 0 ? void 0 : props.chipsItemContainerStyle],
    chipsItemCloseButtonStyle: [{
      backgroundColor: baseColors.chipsItemCloseButtonBackgroundColor,
      justifyContent: 'center',
      alignItems: 'center',
      marginLeft: 8,
      aspectRatio: 1 / 1,
      padding: 8,
      borderRadius: 99
    }, props === null || props === void 0 ? void 0 : props.chipsItemCloseButtonStyle],
    chipsItemCloseIconStyle: [{
      width: 16,
      height: 16,
      tintColor: baseColors.chipsItemCloseButtonIconColor
    }, props === null || props === void 0 ? void 0 : props.chipsItemCloseIconStyle],
    chipsItemTextStyle: [...defaultTextStyle, {
      fontWeight: 'bold'
    }, props === null || props === void 0 ? void 0 : props.chipsItemCloseIconStyle],
    headerContainerStyle: [{
      height: 54,
      flexDirection: 'row',
      alignItems: 'center',
      paddingHorizontal: 16,
      borderBottomWidth: 1,
      borderBottomColor: baseColors.borderColor
    }, props === null || props === void 0 ? void 0 : props.headerContainerStyle],
    headerTextStyle: [...defaultTextStyle, {}, props === null || props === void 0 ? void 0 : props.headerTextStyle],
    headerTitleStyle: [...defaultTextStyle, {
      textAlign: 'center',
      fontWeight: 'bold'
    }, props === null || props === void 0 ? void 0 : props.headerTitleStyle],
    searchInputStyle: [...defaultTextStyle, {
      height: sizes.searchHeight,
      margin: sizes.screenPadding,
      borderWidth: 1,
      borderColor: baseColors.borderColor,
      borderRadius: sizes.searchHeight / 2,
      paddingHorizontal: 16
    }, props === null || props === void 0 ? void 0 : props.searchInputStyle],
    pickerItemContainerStyle: [{
      flexDirection: 'row',
      alignItems: 'center',
      padding: 16,
      opacity: 1
    }, props === null || props === void 0 ? void 0 : props.pickerItemContainerStyle],
    pickerItemTextStyle: [...defaultTextStyle, {
      flex: 1
    }, props === null || props === void 0 ? void 0 : props.pickerItemTextStyle],
    pickerItemIconStyle: [{
      width: 24,
      height: 24,
      marginRight: 8,
      tintColor: baseColors.chipsItemCloseButtonIconColor
    }, props === null || props === void 0 ? void 0 : props.pickerItemIconStyle],
    pickerItemActiveIconStyle: [{
      tintColor: baseColors.textDefaultColor
    }, props === null || props === void 0 ? void 0 : props.pickerItemActiveIconStyle],
    pickerItemDisabledStyle: [{
      opacity: 0.5
    }, props === null || props === void 0 ? void 0 : props.pickerItemDisabledStyle],
    resultTextStyle: [...defaultTextStyle, props === null || props === void 0 ? void 0 : props.resultTextStyle]
  };
};

const AsyncPickerContext = /*#__PURE__*/(0, _react.createContext)(undefined);

const AsyncPickerProvider = _ref => {
  let {
    children,
    configParams = undefined
  } = _ref;
  const colorScheme = (0, _reactNative.useColorScheme)() === 'dark' ? 'dark' : 'light';
  const [configs, setConfigs] = (0, _react.useState)(getInitialConfigs(configParams));
  (0, _react.useEffect)(() => {
    setConfigs(getInitialConfigs(configParams, colorScheme));
  }, [configParams, colorScheme]);
  return /*#__PURE__*/_react.default.createElement(AsyncPickerContext.Provider, {
    value: {
      configs,
      setConfigs
    }
  }, children);
};

exports.AsyncPickerProvider = AsyncPickerProvider;

function useAsyncPicker() {
  const context = (0, _react.useContext)(AsyncPickerContext);

  if (context === undefined) {
    throw new Error('useCount must be used within a CountProvider');
  }

  return context;
}
//# sourceMappingURL=AsyncPickerContext.js.map