function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useState, useRef, forwardRef } from 'react';
import { ActivityIndicator, FlatList, Modal, Platform, SafeAreaView, StatusBar, TextInput, View } from 'react-native';
import AsyncPickerResult from './components/AsyncPickerResult';
import DefaultButton from './components/DefaultButton';
import Header from './components/Header';
import LinkButton from './components/LinkButton';
import PickerItem from './components/PickerItem';
import { useAsyncPicker } from './utils/AsyncPickerContext';
import { isTextIncludedInString } from './utils/helpers';

const AsyncPickerComponent = (_ref, ref) => {
  let {
    modalProps,
    statusBarProps,
    headerProps,
    renderItem,
    keyExtractor,
    labelExtractor,
    data = [],
    limit = 0,
    value = [],
    onChange,
    isLoading = false,
    closeOnSelect = false,
    onClose,
    defaultButtonProps,
    label,
    isSearchable = true,
    searchStringExtractor,
    searchProps,
    defaultPickerItemProps,
    renderButton = _ref2 => {
      let {
        openModal
      } = _ref2;
      return /*#__PURE__*/React.createElement(DefaultButton, _extends({
        label: label,
        onPress: openModal,
        placeholder: value && value.length > 0 ? value.map(el => labelExtractor ? labelExtractor(el) : keyExtractor(el)).join(', ') : undefined
      }, defaultButtonProps));
    },
    ...props
  } = _ref;
  const [isModalVisible, setIsModalVisible] = useState(false);
  const [searchQuery, setSearchQuery] = useState('');
  const {
    configs
  } = useAsyncPicker();
  const inputRef = useRef(null);

  const openModal = () => setIsModalVisible(true);

  const closeModal = () => setIsModalVisible(false);

  const onOptionPress = option => {
    if (limit !== 1) {
      if (value.find(el => keyExtractor(el) === keyExtractor(option))) {
        onChange(value.filter(el => keyExtractor(el) !== keyExtractor(option)));
        return;
      }
    }

    const selectedItems = limit === 1 ? [option] : [...value, option];

    if (limit && limit > 1 && selectedItems.length > limit) {
      return;
    }

    onChange(selectedItems);

    if (onClose) {
      onClose();
    }

    if (closeOnSelect) {
      closeModal();
    }
  };

  const getSearchResult = (query, _data) => {
    const result = _data.filter(el => isTextIncludedInString(query, searchStringExtractor ? searchStringExtractor(el) : labelExtractor(el)));

    return result || [];
  };

  React.useImperativeHandle(ref, () => ({
    openModal,
    closeModal,
    triggerOptionPress: el => {
      onOptionPress(el);
    },
    reset: () => {
      if (onChange) {
        onChange([]);
      }
    },
    getLocalSearchQuery: () => searchQuery,
    focusOnSearch: () => {
      if (inputRef.current) {
        console.log('hello focus');
        inputRef.current.focus();
      }
    }
  }));
  return /*#__PURE__*/React.createElement(View, null, renderButton({
    openModal,
    value
  }), /*#__PURE__*/React.createElement(Modal, _extends({
    animationType: "slide",
    presentationStyle: "formSheet",
    transparent: false,
    visible: isModalVisible,
    onRequestClose: () => {
      closeModal();
    }
  }, modalProps), /*#__PURE__*/React.createElement(SafeAreaView, {
    style: [{
      flex: 1
    }, configs.containerStyle]
  }, /*#__PURE__*/React.createElement(StatusBar, _extends({
    barStyle: Platform.OS === 'ios' ? 'light-content' : 'dark-content'
  }, statusBarProps)), /*#__PURE__*/React.createElement(Header, _extends({
    label: "Search",
    right: /*#__PURE__*/React.createElement(LinkButton, {
      label: "Close",
      onPress: closeModal,
      style: configs.headerTextStyle
    }),
    left: isLoading ? /*#__PURE__*/React.createElement(ActivityIndicator, null) : undefined
  }, headerProps)), isSearchable && /*#__PURE__*/React.createElement(TextInput, _extends({
    ref: inputRef,
    placeholder: 'Search ...',
    autoCapitalize: "none",
    autoCorrect: false,
    clearButtonMode: "while-editing",
    selectTextOnFocus: true
  }, searchProps, {
    value: (searchProps === null || searchProps === void 0 ? void 0 : searchProps.value) || searchQuery,
    onChangeText: el => {
      setSearchQuery(el);

      if (searchProps !== null && searchProps !== void 0 && searchProps.onChangeText) {
        searchProps.onChangeText(el);
      }
    },
    style: [configs.searchInputStyle, searchProps === null || searchProps === void 0 ? void 0 : searchProps.style]
  })), /*#__PURE__*/React.createElement(FlatList, _extends({
    data: searchQuery ? getSearchResult(searchQuery, data) : data,
    keyExtractor: keyExtractor,
    renderItem: _ref3 => {
      let {
        item,
        index,
        separators
      } = _ref3;
      const isActive = value.some(el => keyExtractor(el) === keyExtractor(item));
      const disabled = !isActive && !!limit && limit > 1 && value.length === limit;
      return /*#__PURE__*/React.createElement(React.Fragment, null, renderItem ? renderItem({
        item,
        index,
        separators,
        isActive,
        disabled,
        closeModal,
        onItemPress: onOptionPress
      }) : /*#__PURE__*/React.createElement(PickerItem, _extends({
        label: labelExtractor(item),
        isActive: isActive,
        disabled: disabled,
        onPress: () => onOptionPress(item)
      }, defaultPickerItemProps)));
    },
    ListEmptyComponent: /*#__PURE__*/React.createElement(AsyncPickerResult, {
      mode: !searchQuery ? 'beforeSearch' : 'afterSearch',
      isVisible: !isLoading
    })
  }, props)))));
};

export default /*#__PURE__*/forwardRef(AsyncPickerComponent);
//# sourceMappingURL=AsyncPicker.js.map